@@ -10,20 +10,12 @@ from optparse import make_option
 from django.contrib.auth.models import User
 from django.core import exceptions
 from django.core.management.base import BaseCommand, CommandError
+from django.core.validators import email_re
 from django.utils.translation import ugettext as _
-from emailusernames.utils import create_superuser
-
-
-RE_VALID_USERNAME = re.compile('[\w.@+-]+$')
-
-EMAIL_RE = re.compile(
-    r"(^[-!#$%&'*+/=?^_`{}|~0-9A-Z]+(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*"  # dot-atom
-    r'|^"([\001-\010\013\014\016-\037!#-\[\]-\177]|\\[\001-\011\013\014\016-\177])*"'  # quoted-string
-    r')@(?:[A-Z0-9-]+\.)+[A-Z]{2,6}$', re.IGNORECASE)  # domain
-
+from emailusernames.utils import get_user, create_superuser
 
 def is_valid_email(value):
-    if not EMAIL_RE.search(value):
+    if not email_re.search(value):
         raise exceptions.ValidationError(_('Enter a valid e-mail address.'))
 
 
@@ -72,7 +64,7 @@ class Command(BaseCommand):
                         email = None
 
                     try:
-                        User.objects.get(email__iexact=email)
+                        get_user(email)
                     except User.DoesNotExist:
                         break
                     else:
